/*
 * Copyright 2016 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.script.lang.kotlin

import org.gradle.api.artifacts.Configuration
import org.gradle.api.artifacts.ConfigurationContainer

import org.gradle.api.artifacts.dsl.DependencyHandler


/**
 * The 'archives' configuration.
 */
val ConfigurationContainer.archives: Configuration
    get() = getByName("archives")

/**
* Adds a dependency to the 'archives' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.archives(dependencyNotation: Any) =
    add("archives", dependencyNotation)
    


/**
 * The 'compile' configuration.
 */
val ConfigurationContainer.compile: Configuration
    get() = getByName("compile")

/**
* Adds a dependency to the 'compile' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.compile(dependencyNotation: Any) =
    add("compile", dependencyNotation)
    


/**
 * The 'compileClasspath' configuration.
 */
val ConfigurationContainer.compileClasspath: Configuration
    get() = getByName("compileClasspath")

/**
* Adds a dependency to the 'compileClasspath' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.compileClasspath(dependencyNotation: Any) =
    add("compileClasspath", dependencyNotation)
    


/**
 * The 'compileOnly' configuration.
 */
val ConfigurationContainer.compileOnly: Configuration
    get() = getByName("compileOnly")

/**
* Adds a dependency to the 'compileOnly' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.compileOnly(dependencyNotation: Any) =
    add("compileOnly", dependencyNotation)
    


/**
 * The 'default' configuration.
 */
val ConfigurationContainer.default: Configuration
    get() = getByName("default")

/**
* Adds a dependency to the 'default' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.default(dependencyNotation: Any) =
    add("default", dependencyNotation)
    


/**
 * The 'kapt' configuration.
 */
val ConfigurationContainer.kapt: Configuration
    get() = getByName("kapt")

/**
* Adds a dependency to the 'kapt' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.kapt(dependencyNotation: Any) =
    add("kapt", dependencyNotation)
    


/**
 * The 'kaptTest' configuration.
 */
val ConfigurationContainer.kaptTest: Configuration
    get() = getByName("kaptTest")

/**
* Adds a dependency to the 'kaptTest' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.kaptTest(dependencyNotation: Any) =
    add("kaptTest", dependencyNotation)
    


/**
 * The 'runtime' configuration.
 */
val ConfigurationContainer.runtime: Configuration
    get() = getByName("runtime")

/**
* Adds a dependency to the 'runtime' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.runtime(dependencyNotation: Any) =
    add("runtime", dependencyNotation)
    


/**
 * The 'testCompile' configuration.
 */
val ConfigurationContainer.testCompile: Configuration
    get() = getByName("testCompile")

/**
* Adds a dependency to the 'testCompile' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.testCompile(dependencyNotation: Any) =
    add("testCompile", dependencyNotation)
    


/**
 * The 'testCompileClasspath' configuration.
 */
val ConfigurationContainer.testCompileClasspath: Configuration
    get() = getByName("testCompileClasspath")

/**
* Adds a dependency to the 'testCompileClasspath' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.testCompileClasspath(dependencyNotation: Any) =
    add("testCompileClasspath", dependencyNotation)
    


/**
 * The 'testCompileOnly' configuration.
 */
val ConfigurationContainer.testCompileOnly: Configuration
    get() = getByName("testCompileOnly")

/**
* Adds a dependency to the 'testCompileOnly' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.testCompileOnly(dependencyNotation: Any) =
    add("testCompileOnly", dependencyNotation)
    


/**
 * The 'testRuntime' configuration.
 */
val ConfigurationContainer.testRuntime: Configuration
    get() = getByName("testRuntime")

/**
* Adds a dependency to the 'testRuntime' configuration.
*
* @param dependencyNotation notation for the dependency to be added.
* @return The dependency.
* @see DependencyHandler.add
*/
fun DependencyHandler.testRuntime(dependencyNotation: Any) =
    add("testRuntime", dependencyNotation)
    